
/* ======================================================================== */
/* Hardware driver                                                          */
/* Copyright (c) 2000 Micro-Epsilon                                         */
/* ------------------------------------------------------------------------ */
/* History : 11-FEB-2000                                                    */
/* ======================================================================== */

#ifndef __LIBOPTO_H
   #define __LIBOPTO_H

#ifndef __LIBOPTO__
   #define LIBOPTO __declspec(dllimport)
#else
   #define LIBOPTO __declspec(dllexport)
#endif 

/* ------------------------------------------------------------------------ */
/* Defines                                                                  */
/* ------------------------------------------------------------------------ */

typedef struct
{
   short IfcVersion;
	  short FeatureFlags;
   char  VersionString[40];
} VXD_VERSION_INFO;

typedef struct
{
   UINT uiDevice;
   BOOL bUseSensor_0;
   UINT uiSensorType_0;
   UINT uiSensorRange_0;
   BOOL bUseAutoZero_0;
   double dAutoZero_0;
   BOOL bUseSensor_1;
   UINT uiSensorType_1;
   UINT uiSensorRange_1;
   BOOL bUseAutoZero_1;
   double dAutoZero_1;
   BOOL bUseSensor_2;
   UINT uiSensorType_2;
   UINT uiSensorRange_2;
   BOOL bUseAutoZero_2;
   double dAutoZero_2;
   BOOL bUseSensor_3;
   UINT uiSensorType_3;
   UINT uiSensorRange_3;
   BOOL bUseAutoZero_3;
   double dAutoZero_3;
} PARAMETER_OPTOPCI;

typedef struct
{
   UINT uiCom;
   UINT uiCOMInputSize;
   BOOL bInpOverflow;
   UINT uiInterface;
   UINT uiSensorType;
   UINT uiSensorRange;
   UINT uiAverageType;
   UINT uiAverageN;
   BOOL bOutOfRange;
   BOOL bUseAutoZero;
   double dAutoZero;
} PARAMETER;

#define ILD_1800_RS232          0                        /* RS232 Interface */
#define ILD_1800_RS485          1                        /* RS485 Interface */

#define ILD_NO_SCALE            0                           /* No scaling   */ 
#define ILD_1800_002            1                           /* ILD 1800-2   */
#define ILD_1800_005            2                           /* ILD 1800-5   */
#define ILD_1800_010            3                           /* ILD 1800-10  */
#define ILD_1800_020            4                           /* ILD 1800-20  */
#define ILD_1800_050            5                           /* ILD 1800-50  */
#define ILD_1800_100            6                           /* ILD 1800-100 */
#define ILD_1800_200           13                           /* ILD 1800-200 */
#define ILD_2000_005            7                           /* ILD 2000-5   */
#define ILD_2000_010            8                           /* ILD 2000-10  */
#define ILD_2000_020            9                           /* ILD 2000-20  */
#define ILD_2000_040           10                           /* ILD 2000-40  */
#define ILD_2000_100           11                           /* ILD 2000-100 */
#define ILD_2000_200           12                           /* ILD 2000-200 */

#define ILD_1800_RANGE_UNIPOLAR 0                         /* Unipolar 0...X */ 
#define ILD_1800_RANGE_BIPOLAR  1                     /* Bipolar -X/2...X/2 */ 

#define ILD_1800_AVERAGE_0      0                              /* Average 0 */
#define ILD_1800_AVERAGE_1      1                              /* Average 1 */
#define ILD_1800_AVERAGE_2      2                              /* Average 2 */
#define ILD_1800_AVERAGE_3      3                              /* Average 3 */
#define ILD_1800_AVERAGE_4      4                              /* Average n */

#define IF2004_RANGE_UNIPOLAR   0                         /* Unipolar 0...X */ 
#define IF2004_RANGE_BIPOLAR    1                     /* Bipolar -X/2...X/2 */ 

/* ------------------------------------------------------------------------ */
/* Export functions Opto-PCI-Card IF 2004                                   */
/* ------------------------------------------------------------------------ */

LIBOPTO int OptoPCI_OpenDriver ( char szShortPath[260] );
LIBOPTO int OptoPCI_CloseDriver ( );
LIBOPTO int OptoPCI_DAQ_Info ( VXD_VERSION_INFO *VersionInfo );
LIBOPTO int OptoPCI_DAQ_Parameter ( WORD id, WORD ChanNo, WORD ChanPos[4], UINT SensorType[4], UINT SensorRange[4], double Autozero[4], WORD BlockSize, BOOL encoderOnFIFO, BOOL useGate, WORD sensor);
LIBOPTO int OptoPCI_DAQ_EncoderParam ( WORD id, WORD clock, WORD countingMode, BOOL changeDir, BOOL invert, WORD startValue, WORD refSetting, WORD refValue);
LIBOPTO int OptoPCI_DAQ_EncoderExchange ( WORD id, WORD fkt, WORD *value);
LIBOPTO int OptoPCI_DAQ_SetAverage ( WORD id, BOOL enable[4], BOOL persistant[4], WORD average[4]);
LIBOPTO int OptoPCI_DAQ_Start ( WORD id );
LIBOPTO int OptoPCI_DAQ_Sync();
LIBOPTO int OptoPCI_DAQ_Stop ( WORD id );
LIBOPTO int OptoPCI_DAQ_HalfReady ( WORD id, BOOL *HalfReady );
LIBOPTO int OptoPCI_DAQ_Transfer ( WORD id, WORD *mprVal, double *mprValChan0, double *mprValChan1, double *mprValChan2, double *mprValChan3 );
LIBOPTO int OptoPCI_DAQ_DlgSetup ( PARAMETER_OPTOPCI *ParamDlg, HWND hWndParent, char* helpPath );
LIBOPTO int OptoPCI_DAQ_DlgAutoZero ( PARAMETER_OPTOPCI *ParamDlg, HWND hWndParent, char* helpPath );
LIBOPTO int OptoPCI_DAQ_SensorParam ( WORD id, WORD channel, WORD len, void *param);

/* ------------------------------------------------------------------------ */
/* Function pointers Opto-PCI-Card IF 2004                                  */
/* ------------------------------------------------------------------------ */

typedef int (*OPTO_OPENDRIVER)(char szShortPath[260]);
typedef int (*OPTO_CLOSEDRIVER)();
typedef int (*OPTO_DAQ_INFO)(VXD_VERSION_INFO *VersionInfo);
typedef int (*OPTO_DAQ_PARAMETER)(WORD id, WORD ChanNo, WORD ChanPos[4], UINT SensorType[4], UINT SensorRange[4], double Autozero[4], WORD BlockSize, BOOL encoderOnFIFO, BOOL useGate, WORD sensor);
typedef int (*OPTO_DAQ_ENCODERPARAM)(WORD id, WORD clock, WORD countingMode, BOOL changeDir, BOOL invert, WORD startValue, WORD refSetting, WORD refValue);
typedef int (*OPTO_DAQ_ENCODEREXCHANGE)(WORD id, WORD fkt, WORD *value);
typedef int (*OPTO_DAQ_SETAVERAGE)(WORD id, BOOL enable[4], BOOL persistant[4], WORD average[4]);
typedef int (*OPTO_DAQ_START)(WORD id);
typedef int (*OPTO_DAQ_SYNC)();
typedef int (*OPTO_DAQ_STOP)(WORD id);
typedef int (*OPTO_DAQ_HALFREADY)(WORD id, BOOL *HalfReady);
typedef int (*OPTO_DAQ_TRANSFER)(WORD id, WORD *mprVal, double *mprValChan0, double *mprValChan1, double *mprValChan2, double *mprValChan3);
typedef int (*OPTO_DAQ_DLGSETUP)(PARAMETER_OPTOPCI *ParamDlg, HWND hWndParent, char* helpPath);
typedef int (*OPTO_DAQ_DLGAUTOZERO)(PARAMETER_OPTOPCI *ParamDlg, HWND hWndParent, char* helpPath);
typedef int (*OPTO_DAQ_SENSORPARAM)(WORD id, WORD channel, WORD len, void *param);

/* ------------------------------------------------------------------------ */
/* Export functions optoNCDT 1800 Series                                    */
/* ------------------------------------------------------------------------ */

typedef int (*ILD1800_DAQ_OPEN)(UINT uiCom, UINT uiInterface);
typedef int (*ILD1800_DAQ_CLOSE)(UINT uiCom);
typedef int (*ILD1800_DAQ_INFO)(VXD_VERSION_INFO *VersionInfo);
typedef int (*ILD1800_DAQ_PARAMETER)(UINT uiCom, UINT SensorType, UINT SensorRange, UINT BlockSize, UINT COMInputSize, UINT COMOutputSize, BOOL InpOverflow, BOOL OutOverFlow, BOOL OutOfRange, double AutoZero);
typedef int (*ILD1800_DAQ_START)(UINT uiCom);
typedef int (*ILD1800_DAQ_STOP)(UINT uiCom);
typedef int (*ILD1800_DAQ_GETSTATUS)(UINT uiCom);
typedef int (*ILD1800_DAQ_HALFREADY)(UINT uiCom, BOOL *HalfReady);
typedef int (*ILD1800_DAQ_TRANSFER)(UINT uiCom, double *mprVal, double *mprValBits);
typedef int (*ILD1800_DAQ_POLLING)(UINT uiCom, double *dValue, double *dValueScaled);
typedef int (*ILD1800_DAQ_SETAVERAGE)(UINT uiCom, UINT uiType, UINT uiAvg);
typedef int (*ILD1800_DAQ_RESETCOMMAND)(UINT uiCom);
typedef int (*ILD1800_DAQ_ZEROCOMMAND)(UINT uiCom);
typedef int (*ILD1800_DAQ_DLGAUTOZERO)(PARAMETER *ParamDlg, HWND hWndParent, char* helpPath);
typedef int (*ILD1800_DAQ_DLGFRONTEND)(UINT uiCom, UINT uiInterface, HWND hWndParent, char* helpPath);
typedef int (*ILD1800_DAQ_DLGINFORMATION)(UINT uiCom, UINT uiInterface, HWND hWndParent, char* helpPath);
typedef int (*ILD1800_DAQ_DLGSETUP)(PARAMETER *ParamDlg, HWND hWndParent, char* helpPath);

/* ------------------------------------------------------------------------ */
/* Function pointers optoNCDT 1800 Series                                   */
/* ------------------------------------------------------------------------ */

LIBOPTO int ILD1800_DAQ_Open ( UINT uiCom, UINT uiInterface );
LIBOPTO int ILD1800_DAQ_Close ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_Info ( VXD_VERSION_INFO *VersionInfo );
LIBOPTO int ILD1800_DAQ_Parameter ( UINT uiCom, UINT SensorType, UINT SensorRange, UINT BlockSize, UINT COMInputSize, UINT COMOutputSize, BOOL InpOverflow, BOOL OutOverFlow, BOOL OutOfRange, double AutoZero );
LIBOPTO int ILD1800_DAQ_Start ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_Stop ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_GetStatus ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_HalfReady ( UINT uiCom, BOOL *HalfReady );
LIBOPTO int ILD1800_DAQ_Transfer ( UINT uiCom, double *mprVal, double *mprValBits );
LIBOPTO int ILD1800_DAQ_Polling ( UINT uiCom, double *dValue, double *dValueScaled );
LIBOPTO int ILD1800_DAQ_SetAverage ( UINT uiCom, UINT uiType, UINT uiAvg );
LIBOPTO int ILD1800_DAQ_ResetCommand ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_ZeroCommand ( UINT uiCom );
LIBOPTO int ILD1800_DAQ_DlgAutoZero ( PARAMETER *ParamDlg, HWND hWndParent, char* helpPath );
LIBOPTO int ILD1800_DAQ_DlgFrontEnd ( UINT uiCom, UINT uiInterface, HWND hWndParent, char* helpPath );
LIBOPTO int ILD1800_DAQ_DlgInformation ( UINT uiCom, UINT uiInterface, HWND hWndParent, char* helpPath );
LIBOPTO int ILD1800_DAQ_DlgSetup ( PARAMETER *ParamDlg, HWND hWndParent, char* helpPath );

/* ------------------------------------------------------------------------ */
/* Constants                                                                */
/* ------------------------------------------------------------------------ */

/* Return codes for most of the functions */
#define DRV_FUNCTION_OK       1              /* Ok. Everything worked well.                    */
#define DRV_FUNCTION_FALSE    0              /* An error occured. DRV_INFOSTRUCT.Error         */
                                             /* contains an error code now                     */
/* Status bits */
#define DRV_MEASRUN           0x00010000L    /* Experiment is (still) running                  */
#define DRV_AI_OVRRN          0x00020000L    /* Input buffer overrun                           */
#define DRV_AO_BLOCKEND       0x00040000L    /* Ouput buffer overrun                           */
#define DRV_DATA_LOST         0x00080000L    /* Lost data (e.g. because of lost interrupts)    */
#define DRV_ERROR_STOP        0x00100000L    /* Stopped due to error                           */

/* Error codes and warnings */
#define DRV_ERR_OK                    0x00   /* No error -- everything is fine.                */
#define DRV_ERR_NO386MODE             0x01   /* This driver can only be run in 386enh. mode    */
#define DRV_ERR_NOVDALOGD             0x02   /* The virtual device driver is missing           */
#define DRV_ERR_BUFSIZETOBIG          0x03   /* The driver buffer is too large                 */
#define DRV_ERR_NOCHANNEL             0x04   /* No channel has been specified                  */
#define DRV_ERR_DEVICENOTINIT         0x05   /* The driver is not initialized yet.             */
#define DRV_ERR_NOTENOUGHMEM          0x06   /* Out of memory                                  */
#define DRV_ERR_DLL2DEVICE            0x07   /* DLL + VxD driver don't fit together            */
#define DRV_ERR_OPENCOMX              0x08   /* Error opening the selected COM port            */
#define DRV_ERR_NOHWSUPPORT           0x09   /* No support for this hardware                   */
#define DRV_ERR_MEASRUN               0x0A   /* This function is not allowed during experiment */
#define DRV_ERR_CARDNOTFOUND          0x0B   /* No Hardware was found                          */
#define DRV_ERR_CHANGEGAIN            0x0C   /* Gain list had to be changed                    */
#define DRV_ERR_CHECKHARDWARE         0x0D   /* Installed hardware did not match the setup     */
#define DRV_ERR_WRONGVXD              0x0E   /* Wrong VxD driver                               */
#define DRV_ERR_HARD_CONFLICT         0x0F   /* Experiment could not start due to hardw. confl.*/
#define DRV_WARN_CHANGEFREQ           0x10   /* AI_Frequency had to be changed                 */
#define DRV_WARN_CHANGECHLIST         0x11   /* Channel list had to be changed                 */
#define DRV_ERR_DLL_NOT_FOUND         0x12   /* API DLL cannot found                           */
#define DRV_ERR_DRIVER_VER            0x13   /* No correct API DLL version                     */
#define DRV_ERR_API_FUNCTION          0x14   /* Problems with API functions                    */
#define DRV_ERR_UNKNOWN_SENSOR        0x15   /* Unknown ILD 1800 sensor type                   */
#define DRV_ERR_UNKNOWN_SENSOR_RANGE  0x16   /* Unknown ILD 1800 sensor range                  */
#define DRV_ERR_UNKNOWN_COM           0x17   /* Unknown COM interface                          */
#define DRV_WARN_AI_TOO_FAST          0x18   /* Sampling rate too fast                         */
#define DRV_ERR_BLOCKSIZE             0x19   /* Error in Blocksize                             */
#define DRV_ERR_EXPERIMENT_IS_RUNNING 0x1A   /* Experiment is running                          */
#define DRV_ERR_EXPERIMENT_NOT_RUNS   0x1B   /* Experiment is not running                      */
#define DRV_ERR_ENCODER_NOT_SELECTED	0x1C	 /* The encoder channel was not selected					 */
#define DRV_ERR_ENCODER_WRONG_PARAM   0x1D	 /* A parameter for the encoder was out of range	 */

#ifdef NDEBUG
#  pragma warning(disable:4100)            /* Unreferenced formal parameter */
#  undef  UNUSED
#  define UNUSED(p)
#else
#  pragma warning( error :4100)            /* Unreferenced formal parameter */
#  undef  UNUSED
#  define UNUSED(p) p=p
#endif

#endif



/* ------------------------------------------------------------------------ */
/* End of file                                                              */
/* ------------------------------------------------------------------------ */
